.. _api:

Developer Interface
===================

.. module:: ovmm.commands

This part of the documentation covers all parts of **ovmm**.


Commands
--------

The main functionality of **ovmm** resides in this module. You can see all the
steps performed during execution.
